package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!`````!8``#0````\P0```````#0`(``-
M`"@`'``;``8````T````-````#0```"@`0``H`$```0````$`````P```"`"
M```@`@``(`(``!,````3````!`````$````!````````````````````K`T`
M`*P-```$`````!````$`````$````!`````0``"X4```N%````4`````$```
M`0````!P````<````'```-!,``#03```!``````0```!````W+T``-S-``#<
MS0``/`(``%`"```&`````!````(```#DO0``Y,T``.3-`````0````$```8`
M```$````!````-0!``#4`0``U`$``$P```!,````!`````0````$````L+P`
M`+"\``"PO```(````"`````$````!````%/E=&3X`0``^`$``/@!```H````
M*`````0````$````4.5T9+"P``"PL```L+```!P!```<`0``!`````0```!1
MY71D```````````````````````````&````$````%+E=&3<O0``W,T``-S-
M```D`@``)`(```0````!````!````!0````#````1TY5`$;#Q_<NR/!ICIEA
M$(H%,11[;&HB!````!@````%````1TY5``$``<`$````"0````(``<`$````
M`0```"]L:6(O;&0M;&EN=7@N<V\N,@```@```$4````!````!0`````@`"``
M````10```*U+X\``````````````````````R0(`````````````$@```"4"
M`````````````!(````0`@`````````````2````<0``````````````$@``
M`'L``````````````!(```"*`0`````````````2````RP$`````````````
M$@```%D"`````````````!(```"'```````````````2`````0``````````
M````(````#4"`````````````!(```">`@`````````````2````[`(`````
M````````$@```+D``````````````!(```!A```````````````2````YP``
M````````````$@````,"`````````````!(```#2`0`````````````2````
M_@$`````````````$@```!```````````````"````#<```````````````2
M````=@``````````````$@```+0"`````````````!(````L````````````
M```@````:`(`````````````$@```!8"`````````````!(```"E`@``````
M```````2````4P``````````````$@```"<!`````````````!8````$`0``
M```````````2````:@$`````````````$@```*@``````````````!(```#U
M```````````````2````L0$`````````````$@```($"`````````````!$`
M``"[`@`````````````2````\0$`````````````$@```-H!````````````
M`!(```#H`0`````````````2````S0``````````````$@```*T"````````
M`````!(```#D`@`````````````1````P@$`````````````$@```)H`````
M`````````!(````@`0`````````````2````7@$`````````````$@```/X"
M`````````````!(```#X`0`````````````2````X0$`````````````$@``
M`&<"`````````````!(````L`@`````````````2````.@$`````````````
M$@```!0!`````````````!(````]`@`````````````2````X@(`````````
M````$0```(@"`````````````!(```#:`@`````````````2````1@``````
M````````$0```$\!`````````````!$```#"```````````````2````2P(`
M````````````$@```'L!`````````````!(```"[`0`````````````2````
M;P(`````````````$@```*D!`````````````!(```#"`@`````````````2
M````CP(`````````````(@```*0!`````````````!(```"5`0``!'````0`
M```1`!```%]?9VUO;E]S=&%R=%]?`%])5$U?9&5R96=I<W1E<E1-0VQO;F54
M86)L90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!,7V1O7W5N9'5M<`!0
M97)L7W-Y<U]T97)M`%!E<FQ?9W9?9F5T8VAP=@!P97)L7V9R964`4&5R;%]G
M971?<W8`4&5R;%]A=&9O<FM?=6YL;V-K`'!E<FQ?9&5S=')U8W0`4&5R;%]N
M97=84U]F;&%G<P!P97)L7W)U;@!097)L7VYE=UA3`%!E<FQ?<W9?<V5T<'9N
M`'!E<FQ?86QL;V,`4&5R;%]S=E]S971P=@!P97)L7V-O;G-T<G5C=`!B;V]T
M7T1Y;F%,;V%D97(`4&5R;%]S869E<WES;6%L;&]C`%!,7V-U<G)E;G1?8V]N
M=&5X=`!097)L7V-R;V%K7VYO8V]N=&5X=`!03%]M96UO<GE?=W)A<`!097)L
M7VUG7W-E=`!097)L7V%T9F]R:U]L;V-K`%!E<FQ?<WES7VEN:70S`'!E<FQ?
M<&%R<V4`7TE/7W-T9&EN7W5S960`97AI=`!L<V5E:S8T`')E861D:7(V-`!S
M=')D=7``8VQO<V5D:7(`;W!E;C8T`'-T<G)C:'(`=6YL:6YK`'-T<G1O:P!G
M971P=W5I9`!S=')L96X`<FUD:7(`<F5A9`!?7VUE;6-P>5]C:&L`;6MD:7(`
M7U]V9G!R:6YT9E]C:&L`9V5T<&ED`')E861L:6YK`')E86QL;V,`7U]S<')I
M;G1F7V-H:P!?7VUE;6UO=F5?8VAK`%]?9G!R:6YT9E]C:&L`;'-T870V-`!?
M7VQI8F-?<W1A<G1?;6%I;@!S=&1E<G(`;65M8VAR`%]?8WAA7V9I;F%L:7IE
M`'-T<F-H<@!O<&5N9&ER`&=E='5I9`!A8V-E<W,`;65M8W!Y`'-T<F-M<`!?
M7V5R<FYO7VQO8V%T:6]N`'-T<FYC;7``7U]E;G9I<F]N`%]?<F5G:7-T97)?
M871F;W)K`%]?<W1A8VM?8VAK7V9A:6P`;&EB<&5R;"YS;RXU+C0P`&QI8F,N
M<V\N-@!'3$E"0U\R+C$N,P!'3$E"0U\R+C,T`$=,24)#7S(N-`!'3$E"0U\R
M+C(`1TQ)0D-?,BXS,P!'3$E"0U\R+C,N,@!'3$E"0U\R+C,N-`!'3$E"0U\R
M+C$`1TQ)0D-?,BXP``````(``@`"``$``0`!``,`!``!``$``@`"``4``0`!
M``$`!``"``(``0`!``(``@`!``8`!``"``$``0`!``$``0`!``<``@`"``(`
M`@`"``$``@`"``(``0`"``$`"``"``(`!@`"``$``0`$``(``@`"``$``0`!
M``0``0`"``D``P`"``H``@`!``$`"0`?`P``$`````````!S'VD)```*`"D#
M```0````M)&6!@``"0`U`P``$````!1I:0T```@`0`,``!`````2:6D-```'
M`$H#```0````LY&6!@``!@!4`P``$````'(9:0D```4`7P,``!````!T&6D)
M```$`&L#```0````$6EI#0```P!W`P``$````!!I:0T```(`@0,```````#<
MS0``"````.#-```(````_,\```@````$T```"````!30```(````S,\```8)
M``#0SP``!@H``-3/```&%```V,\```88``#<SP``#AT``.#/```&'@``Y,\`
M``8?``#HSP``!B,``.S/```&*@``\,\```8Z``#TSP``!CL``/C/```&0P``
M\,X```<!``#TS@``!P(``/C.```'`P``_,X```<$````SP``!P4```3/```'
M!@``",\```<'```,SP``!P@``!#/```'"P``%,\```<,```8SP``!PT``!S/
M```'#@``(,\```</```DSP``!Q```"C/```'$0``+,\```<2```PSP``!Q,`
M`#3/```'%0``.,\```<6```\SP``!Q<``$#/```'&0``1,\```<:``!(SP``
M!QL``$S/```''```4,\```<@``!4SP``!R$``%C/```'(@``7,\```<D``!@
MSP``!R4``&3/```')@``:,\```<G``!LSP``!R@``'#/```'*0``=,\```<K
M``!XSP``!RP``'S/```'+0``@,\```<N``"$SP``!R\``(C/```',```C,\`
M``<Q``"0SP``!S(``)3/```',P``F,\```<T``"<SP``!S4``*#/```'-@``
MI,\```<X``"HSP``!SD``*S/```'/```L,\```<]``"TSP``!SX``+C/```'
M/P``O,\```=```#`SP``!T$``,3/```'0@``R,\```=$````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`%.#[`CH)P8``('#V[X``(N#[````(7`=`+_T(/$"%O#_[,$````_Z,(````
M`````/^C#````&@`````Z>#_____HQ````!H"````.G0_____Z,4````:!``
M``#IP/____^C&````&@8````Z;#_____HQP```!H(````.F@_____Z,@````
M:"@```#ID/____^C)````&@P````Z8#_____HR@```!H.````.EP_____Z,L
M````:$````#I8/____^C,````&A(````Z5#_____HS0```!H4````.E`____
M_Z,X````:%@```#I,/____^C/````&A@````Z2#_____HT````!H:````.D0
M_____Z-$````:'````#I`/____^C2````&AX````Z?#^____HTP```!H@```
M`.G@_O___Z-0````:(@```#IT/[___^C5````&B0````Z<#^____HU@```!H
MF````.FP_O___Z-<````:*````#IH/[___^C8````&BH````Z9#^____HV0`
M``!HL````.F`_O___Z-H````:+@```#I</[___^C;````&C`````Z6#^____
MHW````!HR````.E0_O___Z-T````:-````#I0/[___^C>````&C8````Z3#^
M____HWP```!HX````.D@_O___Z.`````:.@```#I$/[___^CA````&CP````
MZ0#^____HX@```!H^````.GP_?___Z.,````:``!``#IX/W___^CD````&@(
M`0``Z=#]____HY0```!H$`$``.G`_?___Z.8````:!@!``#IL/W___^CG```
M`&@@`0``Z:#]____HZ````!H*`$``.F0_?___Z.D````:#`!``#I@/W___^C
MJ````&@X`0``Z7#]____HZP```!H0`$``.E@_?___Z.P````:$@!``#I4/W_
M__^CM````&A0`0``Z4#]____H[@```!H6`$``.DP_?___Z.\````:&`!``#I
M(/W___^CP````&AH`0``Z1#]____H\0```!H<`$``.D`_?___Z/(````:'@!
M``#I\/S___^CS````&B``0``Z>#\____H]````!HB`$``.G0_/___Z/4````
M:)`!``#IP/S___^CV````&B8`0``Z;#\____H]P```!HH`$``.F@_/___Z/@
M````:*@!``#ID/S___^CY````&BP`0``Z8#\____HQ0!``!FD```````````
M`````````````````````/,/'ON-3"0$@^3P_W'\58GE5XG/5E/H50(``('#
M";L``%&#["R+002)1=2+00B)1=!EH10```")1>2-1=!0C4744%'H./___XN#
MZ````(/$#%!0_[,``0``Z$),``"+@PP!``"#Q!"`.``/A!L!``"+@_@```!E
MBP"+%X"(N@(```.-0@0]____/P^'?@$``(U*`X/L#,'@`HE-S%#H?O[__XM-
MU(L_@\00B<:)@T`!``"+`8D&C8,'H___B48$BX,P`0``B48(C8,*H___B48,
M@_\!#XY(`0``B77(C4$$C580C0RY+HVT)@````!FD(LP@\`$@\($B7+\.<%U
M\8MUR(/'`X/L#(V#C$[__\<$O@````!J`%;_=<Q0_[-$`0``Z)G[__^#Q""%
MP`^$C0```(/L#/^S1`$``.A0_?__C57@B<:-@\.A___H,`(``(/$$(7`='Z#
M[`S_LT0!``#H._O__^AV_/__@\00BT7D92L%%`````^%N0```(UE\(GP65M>
M7UV-8?S#Z/#[__^)@T0!``"%P`^$C@```(/L#%#H6?S__XN#^````(/$$&6+
M$,:"7@4```#IM_[__X/L#/^S1`$``.A3^___@\00Z5W___^+@SP!``"%P'01
M@^P,4.C('@``@\00Z6?___^-5>"-@WBA___H@@$``(F#/`$``(7`#X1+____
MZ]%04(V#<Z'___^S$`$``%#H[OS__[\$````Z=G^__^#[`QJ`>B:_?__Z)5*
M``!FD&:0D#'M7HGA@^3P4%12Z!@```"!P]2X``!J`&H`45;_LQ@!``#H.?W_
M__2+'"3#9I!FD(L<),-FD&:09I!FD&:09I#HY````('"G[@``(V*-`$``(V"
M-`$``#G(=!V+@O````"%P'0358GE@^P44?_0@\00R<,NC70F`,.-M"8`````
MZ*0```"!PE^X``!5B>53C8HT`0``C8(T`0``@^P$*<B)P\'H'\'[`@'8T?AT
M%(N2]````(72=`J#[`A04?_2@\00BUW\R<,NC;0F`````)#S#Q[[58GE4^A3
M____@<,'N```@^P$@+LT`0```'4GBX,4`0``A<!T$8/L#/^S(`$``.B9_/__
M@\00Z#'____&@S0!```!BUW\R<,NC70F`/,/'OOI5____XL4),-FD&:09I!F
MD&:09I!FD&:09I"058G55U93Z.7^__^!PYFW``"#[!R+DP@!``"+"H7)#X29
M````#[80A-)T!8#Z/758,?^+,87V=$")3"0,B40D!(GPB<Z);"0(B<6-M@``
M``"#[`17_W0D#%7H<OO__X/$$(7`=0>`?#T`/70TBVX$@\8$A>UUVHGN@\0<
MB?!;7E]=PXVV`````(G'#[97`8/'`832=`6`^CUU\"G'ZY1FD(M$)`B)\BM4
M)`R-=#T!P?H"B1"#Q!R)\%M>7UW#,?;KMRZ-M"8`````C;0F`````%93Z!G^
M__^!P\VV``"#['QEBS44````B70D=(G&C40D%%!6Z'CZ__^#Q!"%P'4YBU0D
M'('B`/```('Z`$```'0(@?H`H```=2&#[`AJ`E;H_/C__X/$$(7`#Y3`#[;`
MZPF-M"8`````,<"+5"1L92L5%````'4&@\1T6U[#Z/Y'```NC;0F`````(VV
M`````%575E/HA_W__X'#.[8``('LC````&6+-10```")="1\B<:%]G0%@#X`
M=26+1"1\92L%%`````^%30$``('$C````%M>7UW#+HVT)@````"0@^P,5NB7
M^/__@\00B<>%P'3)@^P,5^C%^/__@\00A<`/A,H```"-4!.`>!,N=1&`>@$`
M=-TNC;0F`````(UV`(!X$RX/A,8```")5"0(@^P,5NBI^/__BU0D&(G%B10D
MB50D'.B7^/__C4P%`HD,)(E,)!CH]_C__XG%6(V#)*'__UK_="045E#_="0<
M:@)5Z&OY__^#Q!B-1"0D4%7HW??__X/$$(/X_W00BT0D+"4`\```/0!```!T
M=8/L#%7H3/C__X/$$(/L#%7HD/?__X/$$(/L#%?H!/C__X/$$(7`#X4_____
M+HVT)@````"0@^P,5^A7^/__B30DZ)_X__^#Q!#ITO[__XVT)@````"`>@$N
M#X4P____@'H"``^$[O[__^DA____C;0F`````(GHZ'G^___KCNAB1@``9I!5
M5U93Z/?[__^!PZNT``"#[$AEBRT4````B6PD.(G%,<"`.CT/E,"--`)6Z)#W
M__^#Q!")1"0(C50D*(GHZ,[\__^%P`^$%@$``(/L#(G'4.AK]___@\00.T0D
M"`^#W@```(M$)"B+NP@!``#!X`*)1"0,#[9%`(3`#X31`0``/#T/A,D!``")
MZ(VT)@`````/ME`!@\`!A-)T!8#Z/77P*>B+5"0,`Q>#[`R)5"0<BTPD%(U$
M"`)0Z'/W__^+5"0@@\00B0*%P'15BP>+5"0,BQ00#[9%`(@"/#UT)X3`=".-
M10'K#RZ-M"8`````9I"`^3UT#P^V"(/"`8/``8@*A,EU[,8"/3'`C;0F````
M``^V#`:(3`(!@\`!A,EU\8M$)"QE*P44````#X4V`0``@\0\6UY?7<,NC;0F
M`````#'`+HVT)@````"-M@`````/MA0&B!0'@\`!A-)U\NN_B[L(`0``BP^+
M`87`#X3E````,=(NC;0F`````(UT)@")T(/"`8,\D0!U]8T$A0P```")1"04
MBX,X`0``B50D#(7`=72)3"0<@^P,_W0D(,>#.`$```$```#H<O;__XE$)""#
MQ!"%P`^$4O___XM4)`R-#)4`````B50D&(E,)`S_="044?]T)"2)1"0<4.@-
M]___BT0D((M4)"B#Q!")!XM$)!#'1)`$`````.EB_O__C;0F`````(/L"/]T
M)!Q1Z%OT__^)1"0@@\00B0>%P`^$Z?[__XM4)`R-!)4`````B40D#.NY+HVT
M)@````"0,<#I2_[__\=$)!0(````,=+I,/___^CU0P``+HUT)@!55U93@>P`
M$```@PPD`(/L,.AZ^?__@<,NL@``98LM%````(FL)"`0``")U6C_#P``B<>-
M@RJA__^-="0D5E#HW/7__X/$$(7`?A")PHU`_X!\%!L`=3F%P'4QBX/X````
M@^P$55=E_S#H\O/__X/$$(N$)!P0``!E*P44````=3^!Q"P0``!;7E]=PXG"
M9I"#[`12B50D%&HO5NC`]?__@\00A<!TM(N#^````/]T)`Q65V7_,.C%]/__
M@\00Z['H*T,``"Z-M"8`````C78`\P\>^U93Z+7X__^!PVFQ``"#[`2-@X#A
M__^+L_@```!0C8,YH?___[/\````4&7_-NAZ]?__6(V#Y*+__UIJ`%!0C8.,
M8___4(V#5:'__U!E_S;HZ//__X/$)%M>PV:0\P\>^U/H5OC__X'#"K$``(/L
M"(V#@.'__U"-@SFA____L_P```!0BX/X````9?\PZ!OU__^#Q!A;PXVV````
M`/,/'OM55U93@>P`$```@PPD`('L`!```(,,)`"#["SH_/?__X'#L+```&6A
M%````(F$)!P@```QP.CR\?__@^P(C9,UH?__4E"-@VJA__]0:`$0``!J`HUT
M)#96Z'_T__^#Q!QH`!```(V\)",0``!75C'VZ#?T__^#Q!"%P'@N@^P,C5`!
MB<52B50D'.B^\___@\00B<:%P'03_W0D#%574.A9\O__Q@0N`(/$$(N$)!P@
M``!E*P44````=0V!Q"P@``")\%M>7UW#Z+!!``#S#Q[[Z2?___^-M"8`````
M\P\>^U575E.![``0``"##"0`@>R<````Z"/W__^!P]>O``"+O"2P$```98LM
M%````(FL)(P0``"+K"2T$```C40D+(E$)!2)PHV#>*'__^C\]___@^P(:B^)
MQE?H;_'__X/$$(7`=#B-@X&A__^)^NC+^O__B?B+E"2,$```92L5%`````^%
MJ0$``('$G!```%M>7UW#+HVT)@````!FD(/L#%7HM_/__UI9C8N.H?__B4PD
M%%%0Z/3R__^#Q!")Q87`=*.-@Y"A__^)?"00B40D&(V#F:+__XE$)!R-=@"`
M?0``#X26````A?9T$8/L"%56Z)CS__^#Q!"%P'18@^P,5>CX\?__@\00B<>-
M1`7_.<5R%>LF+HVT)@````"0Q@``@^@!.<5T!8`X+W3Q@^P,5>C(\?__@\00
MB<>#[`S_="0<Z+?Q__^#Q!"-1`<"/?\/``!V68/L"/]T)!1J`.A+\O__@\00
MB<6%P`^%;O___XM\)!#I[?[__RZ-="8`A?9T!8`^+G07OP$```"-JW:A___K
MIRZ-M"8`````9I"`?@$`=+'KX2Z-M"8`````@^P$_W0D%/]T)"!5_W0D+&@`
M$```:@*-K"2H````5>@L\O__@\08_W0D'%7HG_#__X/$$(7`#X5K____BT0D
M/"4`\```/0"````/A5?___^#[`AJ`57H9?#__X/$$(7`#X5!____B>J-@X&A
M___H'?G__X/L#%7H-/+__X/$$.E#_O__Z&<_``"-M"8`````\P\>^U93Z/7T
M__^!PZFM``"#[`R+="08:B]6Z-#O__^%P(U0`0]%\HDT).CP\?__@\046U[#
M+HVT)@````!FD/,/'OM55U93@>P`$```@PPD`(/L+.BF]/__@<-:K0``98LU
M%````(FT)!P0``"+M"1`$```A?8/A*,```"`/@`/A)H```"#[`Q6Z#'P__^#
MQ!"-2`&)Q3'`@?D`$```=UN-5"0<@_D$#X.*````A<D/A9H```"-1"K_.<)R
M#.L/Q@``@^@!.=!T!8`X+W3Q@^P(:B]2B50D'.@2[___@\00BU0D#(7`=#<Y
MPG,#Q@``@^P,4N@G\?__@\00BY0D'!```&4K%10```!U8X'$+!```%M>7UW#
M+HVT)@````"0@^P,C8-VH?__4.CQ\/__@\00Z\B-="8`BT0._(G7B40,&(GI
MP>D"\Z7I:/___V:0#[8&B$0D'/;!`@^$5O___P^W1`[^9HE$#!KI1____^CL
M/0``+HVT)@````"-="8`\P\>^U575NB"$@``@<8HK```4X/L+&6+/10```")
M?"0<C;Z2H?__BZX(`0``C50D&(GXZ%CT__^%P'0OBU0D&(M%`(T$D(M0!(D0
MA=)TWI"+4`B#P`2)$(72=?2-5"08B?CH*?3__X7`==&+K@@!``"-OINA__^-
M5"08B?CH#O3__X7`=#6+5"08BT4`C020BU`$B1"%TG3>C;0F`````(M0"(/`
M!(D0A=)U](U4)!B)^.C9\___A<!URXNN"`$``(V^HZ'__XU4)!B)^.B^\___
MA<!T-8M4)!B+10"-!)"+4`2)$(72=-Z-M"8`````BU`(@\`$B1"%TG7TC50D
M&(GXZ(GS__^%P'7+BZX(`0``C;ZLH?__C50D&(GXZ&[S__^%P'0UBU0D&(M%
M`(T$D(M0!(D0A=)TWHVT)@````"+4`B#P`2)$(72=?2-5"08B?CH.?/__X7`
M=<N-AK.A__^+O@@!``")!"2+!"2-5"08Z!KS__^%P'0RBU0D&(L'C020BU`$
MB1"%TG3>C70F`(M0"(/`!(D0A=)U](L$)(U4)!CHZ/+__X7`=<Z+K@@!``"-
MOL.A__^-5"08B?CHS?+__X7`=#2+5"08BT4`C020BU`$B1"%TG3>C;8`````
MBU`(@\`$B1"%TG7TC50D&(GXZ)GR__^%P'7,C89XH?__B[X(`0``B40D!"Z-
M="8`BT0D!(U4)!CH<_+__X7`="^+5"08BP>-!)"+4`2)$(72=-TNC;0F````
M`"Z-="8`BU`(@\`$B1"%TG7TZ\)FD(V&SZ'__XN^"`$``(E$)`R+1"0,C50D
M&.@C\O__A<!T+XM4)!B+!XT$D(M0!(D0A=)TW2Z-M"8`````+HUT)@"+4`B#
MP`2)$(72=?3KPF:0C8;9H?__B[X(`0``B40D"(M$)`B-5"08Z-/Q__^%P'0O
MBU0D&(L'C020BU`$B1"%TG3=+HVT)@`````NC70F`(M0"(/`!(D0A=)U].O"
M9I"+K@@!``"-ON.A__^-5"08B?CHB?'__X7`=#"+5"08BT4`C020BU`$B1"%
MTG3>9I"+4`B#P`2)$(72=?2-5"08B?CH6?'__X7`=="+K@@!``"-OH&A__^-
M5"08B?CH/O'__X7`=#6+5"08BT4`C020BU`$B1"%TG3>C;0F`````(M0"(/`
M!(D0A=)U](U4)!B)^.@)\?__A<!URXU4)!B-ANVA___H]O#__X7`=`N)PHM$
M)`CHU_/__XU4)!B-AOZA___HV/#__X7`=`V)PHV&$*+__^BW\___C50D&(V&
M&Z+__^BX\/__A<!T+8G"BT0D!.B9\___BT0D'&4K!10```!U-8L$)(/$+(V6
M/*+__UM>7UWI=_/__XU4)!B-ABNB___H>/#__X7`=,N)PHM$)`SH6?/__^N^
MZ+(Y``!FD/,/'OOH40X```7[IP``@^P<98L5%````(E4)`R-5"0(C8#/H?__
MZ#7P__^%P'0Q#[80@/HP#Y3`A-(/E,()T(/P`0^VP(M4)`QE*Q44````=1*#
MQ!S#+HVT)@````!FD#'`Z^'H1SD``(VT)@````#S#Q[[4^C6[O__@<.*IP``
M@^P(C40D%%#_="04BX,$`0``:@+_,.@%ZO__QP0D_P```.@)[/__+HVT)@``
M``"055=64XV<)```__^![``0``"##"0`.=QU\H/L+.A_[O__@<,SIP``98LM
M%````(FL)!P``0")Q6H":@!J`%7HG>O__X/`_X/2_XE$)!B+="08B=>)5"0<
MP?\?,?@I^#'2)?__```Q^C'X*?@9^HM\)!PIQHET)!@9UXE\)!R#Q!"-="04
MA?\/B,P```"-="8`:@#_="00_W0D$%7H0.O__X/$$"'0@_C_#X3"````@^P$
M:`@``0!65>CCZ/__@\00@_C_#X28````@_@'=F*-1`;X.?!R6HT])`$``.L9
M+HVT)@`````NC;0F`````&:0@^@!.?!R.8L0BT@$,Q0?,TP?!`G*=>DI\)D#
M1"0($U0D#(N,)!P``0!E*PT4````=5V!Q"P``0!;7E]=PXUV`(%$)`@``/__
MBU0D"(-4)`S_BTPD#(G0B<HU``#___?2"=`/A3C___^X_____XG"Z[&#[`R-
M@TNB__]0Z%#^__^#[`R-@SZB__]0Z$'^___H?#<``"Z-M"8`````C70F`/,/
M'OM3Z`;M__^!P[JE``"#[`CH^.C__X/L#%#HS^C__X/$$(7`=`*+`(/$"%O#
MD/,/'OM55U93Z-/L__^!PX>E``"#["QEBST4````B7PD'(M\)$"-5"08C;-7
MHO__B?#HNNW__X7`=`6`.`!U(8M$)!QE*P44````#X6#````@\0LB?J)\%M>
M7UWI@/#__XE$)`B#[`Q7Z#/H__^+5"08B<6)%"2)5"0<Z"'H__^-3`4"B0PD
MB4PD&.B!Z/__@\0,B<6-@XZA____="004(V#F:+__U=0_W0D'&H"5>CMZ/__
M@\0@BT0D'&4K!10```!U$(/$+(GJB?!;7E]=Z0WP___H:#8``"Z-M"8`````
M\P\>^^CP[/__@<*KI```C4PD!(/D\/]Q_%6)Y5=64U&![`@!``"+`8F5%/__
M_XF%`/___XV"=J'__V8/;M!EBPT4````B4WDB=&-DFZB___'18``````9@]N
MPL=%K`````!F#V+"QT60`````&8/UH5X____C8%[HO__C9$FHO__9@]NRF8/
M;MB-D0FB__^-@7.B__]F#V["9@]BRV8/;N"-D7^B__^-@82B__]F#V+$9@]N
MZ(V!>*'__V8/;,&)A?3^__\/$46<9@]NPHV5&/___V8/8L6)E03___]F#]9%
MB.@I[/__A<!T"8`X``^%+`4``(N=%/___^@!Y___@^P,4.C8YO__@\00A<`/
MA(T$``"+.(7_#X2#!```@^P,5^B:YO__@\00C70``8/L#%:+G13____H].;_
M_X/$$(GQB<(/M@>)E?C^__^$P'1WBYT4____B8T(____C9N-HO__B9T,____
M+HVT)@````"#[`P/ML"#QP%0_[4,____5FH"4HN=%/___XF5$/___^@KY___
MBX4(____BY40____.?")PP]"WHG8*?"#P`(YV`]"PRG>@\("@\0@C70&_@^V
M!X3`=:F+A13___^+O03___^-79R-@!"B___K"V:0BP.#PP2%P'0WB?KH(.O_
M_XG&A<!TZH`X`'3EZ.#K__^%P'3<@^P,5HN=%/___^@-Y___@\00B<>%P'5)
MC70F`(VU>/___^L++HVT)@````"#Q@2+/H7_="R`/P`/A$X#``")^.B7Z___
MA<!TXX/L#%>+G13____HQ.;__X/$$(G'A<!TRX/L#%>+G13____H3.7__UK_
MM?C^__^)QN@^Y?__C;0&!`0``(FU#/___XDT).B9Y?__B840____B<*-@Y*B
M____M?C^__]0C8.0H?__B84(____4(V#EZ+__U>)UU!6:@)2Z/3E__^#Q"AH
MP`$``%?H1N/__X/$$(/X_W40Z!GC__^+`(/X$0^%"@,``(/L"/^U!/____^U
M$/___XN=%/___^ATY?__@\00B<>%P'13@^P,_[40____BX4`_____S"+G13_
M__^-@TRC__]0BX,$`0``,?9J`O\PZ"SC__^#Q""+1>1E*P44````#X7!!```
MC67PB?!96UY?78UA_,.-=@"+A2C___\E`/```#T`0```=9N+G13___^+M3#_
M___H=>3__SG&=8:+A2C___\E_P$``#W``0``#X5P____@^P,_[4,____BYT4
M____Z'?D__^+E03___^)QHV#8J+__^A$Z?__@\00A<`/A*D"``"#[`A0BX4`
M_____S#HV/#__X/$$(F%^/[__X7`#X2'`@``@^P,_[7X_O__BYT4____Z+/C
M__^#Q!")PH/X`W9)@^P(C8.@HO__4(N%^/[__XF5\/[__XU$$/Q0Z!GE__^#
MQ!"%P'4BBY7P_O__@_H$#X1B`P``BX7X_O__@'P0^R\/A%$#``!FD(N%%/__
M_XN5!/___XV`SZ'__XF%`/___^B3Z/__A<`/A!,"```/M@"$P`^$"`(``#PP
M#X0``@``BYT4____BX4`____C9,\HO__Z%'K___H7.'__XV3Y*+__XF5!/__
M_U)0C8/$HO___[4(_____[40____4/^U#/___VH"5NC=X___C8/2HO__@\0@
MB84`____ZTJ-="8`Z`/A__^#.!%U6(N=%/___X/'`>@`X?__@^P,_[4$____
M5U#_M0C_____M1#_____M0#_____M0S___]J`E;HA>/__X/$,(/L"&C``0``
M5HN=%/___^C.X/__@\00@_C_=)Z#[`S_M1#___^+G13____HLN'__XN%]/[_
M_XGRZ(7J__^)-"3HG?G__X/$$.F\_?__+HUT)@`Q_^G._/__+HVT)@````"0
MC76(ZP:-=@"#Q@2+!H7`#X26````BY4$____Z%#G__^%P'3D@#@`=-^#[`Q0
MBYT4____Z$CC__^#Q!"%P'3)@^P,B<=0BYT4____Z-#A__^#Q!"-=``!Z3'[
M__^#[`A0_[40____BX4`_____S"+G13___^-@Q"C___I$_W__Y"#[`Q0B840
M____Z/'X__]9_[40____BYT4____Z-_B__^#Q!")QNG\_/__@^P,O@T```!J
M#8N=%/___XV[9Z+__^C*X?__@\00N0T```")A?C^__^)PKA3````Z=#Z__^+
MA0#___^+`(F%^/[__^EF_?__+HUT)@"#[`AJ`/^U^/[__XN=%/___^BRW___
M@\00A<`/A-_]__^)A03____HG/;__XF%^/[__XF5_/[__X72#XC`_?__@\#V
M:@"#TO]24/^U!/___XN=%/___^A-XO__@\0,C46U:@90_[4$____Z/G?__^#
MQ!"+C03___^#^`8/A00!``"!?;4`0T%##X5R_?__9H%]N4A%#X5F_?__:@"+
MA?C^__^-?;N+E?S^__^#P,Z#TO]24%&+G13___^)C03____HX^'__X/$#&HH
M5_^U!/___^B2W___@\00@_@H#X6C````C8/DHO__QD7C`%"-@[6B__]7_[4(
M_____[40____4/^U#/___VH"5N@9X?__@\0@Z:O]__^+A0#___^+2`2%R0^$
MH/S__X/L#%&+G13___^)C0#____HZ]___X/$$(/X`P^&?_S__X/L"(V3I:+_
M_U*+C0#___^-1`'\4.A5X?__@\00BXT`____A<`/18WX_O__B8WX_O__Z4C\
M___H0RX``(N%%/___X/L#(V`JJ+__U#H[O3__RZ-M"8`````C;8`````\P\>
M^U575E/HL^/__X'#9YP``(/L'(U\)`B)^F6+-10```")="0,B[/X````98LN
M#[9%:(A%:8V#LZ'__^B.Y/__A<!T"8`X,0^$20$``.CL[___98LNC8/CHO__
M:@-J`5!5Z!C>__^#Q!")Q87`="F#[`2-@^6B__]0BT4,_S!E_S;H"-[__XM%
M#(/$$(L`]D`*0`^%+@$``(V#ZJ+__VH#:@%09?\VZ-/=__^#Q!")Q87`="J)
M^HV#@:'__^@-Y/__BU4,BPJ%P`^$X````(/L!%!19?\VZ+/=__^#Q!"#[`2-
M@^RB__]J`5!E_S;H#-W__X/$#(V3`:/__U)09?\VZ(G=__]EBP:)^L9`:0"-
M@WBA___HM>/__X/$$(F#/`$``(G&A<!T/H/L"&C``0``5NBHW/__@\00C5`!
M@_H!=@F#^!$/A9````"+1"0,92L%%`````^%E0```(/$'%M>7UW#C78`@^P,
M_[-``0``Z$KV__^#Q!")@SP!``")QH7`=:6#[`R-@Z"C__]0Z,S>__^-="8`
M@'@!``^$M?[__^FH_O__+HVT)@````"0BX-``0``BQ")R.AQZ/__Z1S___^-
M="8`@^P(4&7_-N@LWO__@\00Z;[^__]0BX-``0``5O\PC8/$H___4.ANWO__
MZ"DL```NC;0F`````)#S#Q[[5E/HM>'__X'#:9H``(/L)&6+-10```")="0<
MBW0D,(U4)!B-@\^A___HGN+__X7`=!L/MA"$T@^4P(#Z,`^4P@C0=0F%]G0%
M@#X`=1>+1"0<92L%%````'5G@\0D6U[#C70F`(/L#%;HC^S__UI9:B]0B40D
M'.@QW/__B<&-0`&%R0]$1"0<B00DZ$W>__^#Q`R-DY*B__]J!%)0Z/O=__^#
MQ!"%P'6EBT0D'&4K!10```!U#(/$)(GP6U[I:^/__^A6*P``BP0DPXLT),-F
MD&:09I!FD&:09I!FD%6)Y5?H]2H``(''BYD``%93@^3P@>P0`P``B7PD4(V\
M)(````")1"1<98LU%````(FT)`P#``"-<#B-A"0``0``B40D8"Z-M"8`````
MC78`BTX$BP8QV\=$)'0`````,=(+5"1TQT<$`````(/&"`_(B0>)R`G:B4PD
M:,'H",'I&#';B4PD<(M,)&@)VH/'$(E$)'B+1"1XP>$8B5?\)0#_```+1"1P
MQT0D;``````)R(M,)&C'1"1\`````,'A"('A``#_``G(B4?X.7PD8`^%>___
M_XM\)%"-A"3H````9@]OA"20````C90DZ`(``&8/;Y0DH````&8/;XPDL```
M`&8/;Z>,X?__C;8`````\P]O*&8/;]EF#V](V(/`$&8/[T"(9@_OZ68/[\5F
M#V_H9@]S\`%F#W/5'V8/Z\5F#]O$#RE`"&8/;\)F#V_3.<)UO8M<)%R+4PR+
M,XM[!(M#"(M+$(E4)$2)VHM;%(E$)$")\(E,)'C!X`6)7"1\B=.+4AB+2QR)
M5"0XBU,@B4PD/(M+)(E4)`B)3"0,B?$/K/D;"<B+3"0(`XPD@````('!F7F"
M6@'(BTPD>#-,)#@C3"1`,TPD.`'(,=*)1"1@BT0D0(E4)&2+5"1$B<'!X1X/
MK-`""<&)3"1HB4PD4(M,)'B+1"10BUPD.(ET)$B)?"1,BWPD3#'((?`QR`.<
M)(@```")V8G&BUPD9('!F7F"6@'.BTPD8(G(#ZS9&\'@!0G(`<8QTHET)'"+
M="1(B50D=(M4)&B)\8GPP>$>#ZSX`HG+"<.+1"1@,=J)7"0PB5PD*"'0BUPD
M>#-$)%`#G"20````B=F)QHM<)'2!P9EY@EH!SHM,)'")R`^LV1N+7"1@P>`%
M"<B)V@'&P>(>BT0D,#')B70D:(MT)&2)3"1L#ZSS`HG6"=XQ\(ET)"`C1"1P
MB70D,#-$)"B+="10`[0DF````(GQB<:+7"1L@<&9>8):`<Z+3"1HB<@/K-D;
MBUPD<,'@!0G(B=H!QL'B'C')B70D8(MT)'2)T(M4)#")3"1D#ZSS`HMT)"@)
MV(M<)&2)1"10,<*)1"08BT0D:"'0,T0D(`.T)*````")\8G&@<&9>8):`<Z+
M3"1@B<@/K-D;BUPD:,'@!0G(B=H!QL'B'HM$)%`QR8ET)'"+="1LB4PD=`^L
M\P*)U@G>,?")="0P(T0D8(ET)%`S1"08BW0D(`.T)*@```")\8G&@<&9>8):
M`<Z+3"1PBUPD=(G(#ZS9&XM<)&#!X`4)R(G:`<;!XAXQR8ET)&B+="1DB="+
M5"10B4PD;`^L\P*+="08"=B+7"1LB40D4#'"B40D*(M$)'`AT#-$)#`#M"2P
M````B?&)QH'!F7F"6@'.BTPD:(G(#ZS9&XM<)'#!X`4)R(G:`<;!XAZ+1"10
M,<F)="1@BW0D=(E,)&0/K/,"B=8)WHM<)&0Q\(ET)"`C1"1HB70D4#-$)"B+
M="0P`[0DN````(GQB<:!P9EY@EH!SHM,)&")R`^LV1N+7"1HP>`%"<B)V@'&
M,<G!XAZ)3"1TB=")="1PBW0D;(M4)%`/K/,"BW0D*`G8BUPD=(E$)%`QPHE$
M)#"+1"1@(=`S1"0@`[0DP````(GQB<:!P9EY@EH!SHM,)'")R`^LV1N+7"1@
MP>`%"<B)V@'&P>(>BT0D4#')B70D:(MT)&2)3"1L#ZSS`HG6"=Z+7"1LB70D
M4#'P(T0D<(ET)"@S1"0PBW0D(`.T),@```")\8G&@<&9>8):`<Z+3"1HB<@/
MK-D;BUPD<,'@!0G(B=H!QL'B'C')B70D8(MT)'2)T(M4)%")3"1D#ZSS`@G8
M,<*)1"0@B40D4(M$)&B+="0PBUPD9"'0,T0D*`.T)-````")\8G&@<&9>8):
M`<Z+3"1@B<@/K-D;BUPD:,'@!0G(B=H!QL'B'HM$)%`QR8ET)'"+="1LB4PD
M=`^L\P*)U@G>BUPD=(ET)%`Q\"-$)&")="0P,T0D((MT)"@#M"38````B?&)
MQH'!F7F"6@'.BTPD<(G(#ZS9&XM<)&#!X`4)R(G:`<;!XAXQR8ET)&B+="1D
MB="+5"10B4PD;`^L\P*+="0@"=@QPHE$)"B)1"10BT0D<"'0,T0D,`.T).``
M``")\8G&BUPD;('!F7F"6@'.BTPD:(G(#ZS9&XM<)'#!X`4)R(G:`<;!XAZ+
M1"10,<F)="1@BW0D=(E,)&0/K/,"B=8)WHM<)&2)="10,?`C1"1HB70D(#-$
M)"B+="0P`[0DZ````(GQB<:!P9EY@EH!SHM,)&")R`^LV1N+7"1HP>`%"<B)
MV@'&P>(>,<F)="1PBW0D;(G0BU0D4(E,)'0/K/,"BW0D*`G8BUPD=#'"B40D
M,(E$)%"+1"1@(=`S1"0@`[0D\````(GQB<:!P9EY@EH!SHM,)'")R`^LV1O!
MX`4)R`'&,<F)="1HB4PD;(M<)&"+="1DBT0D4(G:P>(>#ZSS`HG6"=Z+7"1L
MB70D4#'P(T0D<(ET)"@S1"0PBW0D(`.T)/@```")\8G&@<&9>8):`<Z+3"1H
MB<@/K-D;BUPD<,'@!0G(B=H!QL'B'C')B70D8(MT)'2)T#'2B50D)(M4)%`/
MK/,"BW0D,(E,)&0)V(M<)&0QPHE$)"")1"1PBT0D:"'0,T0D*`.T)``!``")
M\8G&@<&9>8):`<Z+3"1@B<@/K-D;BUPD:,'@!0G(B=H!QC')P>(>B70D4(MT
M)&R)T(E,)%2)\0^DV1X/K/,"P>X"B<J)V8GSB<:)UPG.,<D)WXET)#")3"0T
MBT0D<(ET)&B+7"14,?"+="0H(T0D8(E\)&PS1"0@`[0D"`$``(GQB<:!P9EY
M@EH!SHM,)%")R`^LV1N+7"1@P>`%"<B)V@'&P>(>,?^)="1PBW0D9(G0B7PD
M=(M\)%2)\0^DV1X/K/,"B<K![@(QR0G8"?*)3"0<BTPD;(G6BU0D:(M<)"2)
M1"08,?&)="1DBW0D4#'"B40D8(G0B<J+3"0@(?`A^C-$)#`S5"0T`XPD$`$`
M`!.<)!0!``"!P9EY@EJ#TP`!P1'3B4PD:(M,)'")7"1LBUPD=(G(P>`%#ZS9
M&XGS"<B+3"1H`<&)\`^L^P*)RHE,)"C!X!XQR8E4)&B)^@^D\AZ)_HE,)&R)
MV<'N`HG7B?.)Q@G."=^)\8G[BW0D8(M\)&2)3"10,<XQWXM<)#")\(GZ(T0D
M<"-4)'0S1"08,U0D'`.<)!@!``"+="0TB=D3M"0<`0``B?.!P9EY@EJ#TP")
MS@'&B=\1UXET)&"+="1HB7PD9(M\)&R)\(GS#ZS[&\'@!0G8BUPD8`'#,<F)
M3"1DBTPD<(E<)"")SHE<)&"+7"1TP>8>B?")S@^LW@*)\8G&BT0D&`G.BTPD
M*(GRBW0D4(E4)#`QUC'Q`X0D(`$``(M<)&2)SHM,)&`%H>O9;@'&B<@/K-D;
MBUPD;,'@!0G(`<8QR8E,)'2+3"1HB70D&(G(#ZS9`HN<)"@!``")="1PP>`>
MB[0D+`$```G(@<.AZ]EN@]8`B=F)1"0H,?^)\XMT)%"+1"0@`?&+="0P$?LS
M="0H,=(Q\`'!$=.)3"1HBTPD<(E<)&R+7"1TB<B)WHG+P>`%BTPD:`^L\QN+
M="0H"=B+7"1D`<&)RHE,)"`QR8E,)&R+3"1@B50D:(G(#ZS9`HN<)#`!``#!
MX!X)R('#H>O9;HE$)%"+1"0PB=D!P8M$)!@S="10B<N+3"1H,?`!PXG(B=Z+
M7"1LP>`%#ZS9&XM<)'0)R(M,)'`!QC'2B<B)="08#ZS9`HN<)#@!``#!X!Z)
M="1@B<:+1"0@B50D9`G.@<.AZ]ENB70D,(NT)#P!``")V8/6`#'_B?.+="0H
M`?&+="10$?LS="0P,=(Q\`'!$=.)3"1PBTPD8(E<)'2+7"1DB<B)WHG+P>`%
MBTPD<`^L\QN+="0P"=B+7"1L`<&)RHE,)"`QR8E,)'2+3"1HB50D<(G(#ZS9
M`HN<)$`!``#!X!X)R('#H>O9;HE$)"B+1"10B=D!P8M$)!@S="0HB<N+3"1P
M,?`!PXG(B=Z+7"1TP>`%#ZS9&PG(`<8QTHET)!B)="1HBTPD8(M<)&2)5"1L
MB<C!X!X/K-D"BYPD2`$``(G&BT0D(`G.@<.AZ]ENB70D4(NT)$P!``")V8/6
M`#'_B?.+="0P`?&+="0H$?LS="10,=(Q\`'!$=.)3"1@BTPD:(E<)&2+7"1L
MB<B)WHG+P>`%BTPD8`^L\QN+="10"=B+7"1T`<&)RHE,)"`QR8E,)&2+3"1P
MB50D8(G(#ZS9`HN<)%`!``#!X!X)R('#H>O9;HE$)#"+1"0HB=D!P8M$)!@S
M="0PB<N+3"1@,?`!PXG(B=Z+7"1DP>`%#ZS9&PG(BTPD:`'&,=*)="08B<B)
M="1PP>`>B50D=(M<)&R)QHM$)"`/K-D"BYPD6`$```G.B70D*(NT)%P!``"!
MPZ'KV6Z)V8/6`#'_B?.+="10`?&+="0P$?LS="0H,=(Q\`'!$=.)3"1HBTPD
M<(E<)&R+7"1TB<B)WHG+P>`%BTPD:`^L\QN+="0H"=B+7"1D`<&)RHE,)"`Q
MR8E,)&R+3"1@B50D:(G(#ZS9`HN<)&`!``#!X!X)R('#H>O9;HE$)%"+1"0P
MB=D!P8M$)!@S="10B<N+3"1H,?`!PXG(B=Z+7"1LP>`%#ZS9&XM<)'0)R(M,
M)'`!QC'2B<B)="08#ZS9`L'@'HET)&")QHE4)&0)SHET)#"+G"1H`0``B[0D
M;`$``(M$)""!PZ'KV6Z#U@")V3'_B?.+="0H`?&+="10$?LS="0P,=(Q\`'!
M$=.)3"1PBTPD8(E<)'2+7"1DB<B)WHG+P>`%BTPD<`^L\QN+="0P"=B+7"1L
M`<&)RHE,)"`QR8E,)'2+3"1HB50D<(G(#ZS9`HN<)'`!``#!X!X)R('#H>O9
M;HE$)"B+1"10B=D!P8M$)!@S="0HB<N+3"1P,?`!PXG(B=Z+7"1TP>`%#ZS9
M&XM<)&0)R(M,)&`!QC'2B<B)="08#ZS9`HN<)'@!``#!X!Z)="1HB<:)5"1L
M"<Z!PZ'KV6Z)="10B[0D?`$``(G9@]8`,?^)\XMT)#"+1"0@`?&+="0H$?LS
M="10,=(Q\`'!$=.)3"1@BTPD:(E<)&2+7"1LB<B)WHG+P>`%BTPD8`^L\QN+
M="10"=B+7"1T`<&)RHE,)"`QR8E,)&2+3"1PB50D8(G(#ZS9`HN<)(`!``#!
MX!X)R('#H>O9;HE$)#"+1"0HB=D!P8M$)!@S="0PB<N+3"1@,?`!PXG(B=Z+
M7"1DP>`%#ZS9&XM<)&P)R(M,)&@!QC'2B<B)="08#ZS9`HN<)(@!``#!X!Z)
M="1PB<:)5"1T"<Z!PZ'KV6Z)="0HB[0DC`$``(G9@]8`,?^)\XMT)%`!\8MT
M)#`1^S-T)"B+1"0@,=(Q\`'!$=.)3"1HBTPD<(E<)&R+7"1TB<B)WHG+P>`%
MBTPD:`^L\QN+="0H"=B+7"1D`<&)3"0@B<HQR8E,)&R+3"1@B50D:(G(#ZS9
M`HN<))`!``#!X!X)R('#H>O9;HE$)%"+1"0PB=D!P8M$)!@S="10B<N+3"1H
M,?`!PXG(B=Z+7"1LP>`%#ZS9&XM<)'0)R(M,)'`!QC'2B<B)="08#ZS9`HN<
M))@!``#!X!Z)="1@B<:+1"0@B50D9`G.@<.AZ]ENB70D,(NT))P!``")V8/6
M`#'_B?.+="0H`?&+="10$?LS="0P,=(Q\`'!$=.)3"1PBTPD8(E<)'2+7"1D
MB<B)WHG+P>`%BTPD<`^L\QN+="0P"=B+7"1L`<&)3"00B<HQR8E,)'2+3"1H
MB50D<(G(#ZS9`HN<)*`!``#!X!X)R('#H>O9;HE$)"B+1"10B=D!P8M$)!@S
M="0HB<N+3"1P,?`!PXG(B=Z+7"1TP>`%#ZS9&XM<)&0)R(M,)&`!QC'2B<B)
M="1H#ZS9`HN<)*@!``#!X!Z)="08B<:+1"00B50D;`G.@<.AZ]ENB70D((NT
M)*P!``")V8/6`#'_B?.+="0P`?&+="0H$?LS="0@,=(Q\(MT)&@!P1'3B4PD
M8(GPB5PD9(M\)&R)\\'@!8M,)&"+="0@#ZS[&XM\)&P)V(M<)'0!P8E,)!")
MRC')B4PD5(M,)'")5"10BY0DN`$``(G(#ZS9`HM<)%3!X!X)R(N,)+`!``")
M1"0PBT0D*('!H>O9;@'!BT0D&#-T)#`Q\(G.BTPD4`'&B<@/K-D;P>`%"<@!
MQHM$)"")\S'VB70D=(MT)&B)7"1PBUPD=(GQ#ZS^`L'A'@G.,<F!PJ'KV6Z)
M3"0<B=$!P8M$)#")="1@B70D&#'P,T0D$`'!B4PD:(M,)'")R(G*P>`%#ZS:
M&XG&"=:)\`-$)&@QR8E$)&B)3"1LBU0D5(M$)%"+="1@B=.+?"1T#Z3#'HG!
M#ZS0`L'J`L'A'@G3"<&)VB'.B<@+1"1@B50D)(N4),`!```QVR-$)'")3"0@
MB4PD*`G&BTPD,('"W+P;CXG0B5PD+(M<)&P!R(M,)&B+5"0@`<:)R`^LV1O!
MX`4)R`'&BT0D:(GS,?:)="1DBW0D<(E<)&"+7"1DB?$/K/X"P>$>"<XQR8E,
M)!2+3"0H"?(AT(ET)%`A\8ET)!`)R(M,)!@#C"3(`0``@<'<O!N/`<&)3"1P
MBTPD8(G(B<K!X`4/K-H;B<8)UHGP`T0D<#')B40D<(E,)'2+1"1HBU0D;(MT
M)%")P8M\)&2)T\'A'@^DPQX/K-`""<'!Z@*)R(E,)"`+3"10"=,C3"1@(<:)
M1"0P,=()\8M$)"@#A"30`0``B5PD)(G.BTPD<(M<)'0%W+P;CP'&B50D-(G(
M#ZS9&\'@!0G(`<8QR8M$)'")\S'VB4PD'(M,)"")="1LBW0D8(E<)&B+7"1L
MB?(/K/X"P>(>"=8)\8ET)%`AR(M,)#")="08(?$)R(M,)!`#C"38`0``@<'<
MO!N/`<&)3"1@BTPD:(G(B<K!X`4/K-H;B<8)UHGP`T0D8#')B40D8(M$)'"+
M5"1TBW0D4(E,)&2)P8M\)&R)T\'A'@^DPQX/K-`""<'!Z@*)R(E,)"`+3"10
M"=,C3"1H(<:)1"0H,=()\8M$)#`#A"3@`0``B5PD)(G.BTPD8(M<)&0%W+P;
MCP'&B50D+(G(#ZS9&\'@!0G(`<8QR8M$)&")\S'VB4PD%(M,)"")="1TBW0D
M:(E<)'"+7"1TB?(/K/X"P>(>"=8)\8ET)%`AR(M,)"B)="00(?$)R(M,)!@#
MC"3H`0``@<'<O!N/`<&)3"1HBTPD<(G(B<K!X`4/K-H;B<8)UHGP`T0D:(M4
M)&0QR8MT)%"+?"1TB40D:(M$)&")3"1LB=.)P0^DPQ[!X1X/K-`""<'!Z@*)
MR(E,)"`+3"10"=,C3"1P(<:)1"0P,=()\8M$)"@#A"3P`0``B5PD)(G.BTPD
M:(M<)&P%W+P;CP'&B50D-(G(#ZS9&\'@!0G(`<8QR8M$)&B)\S'VB4PD'(M,
M)"")="1DBW0D<(E<)&")\@^L_@+!XAX)U@GQB70D4"'(BTPD,(ET)!@A\0G(
MBTPD$`.,)/@!``"!P=R\&X\!P8E,)'"+3"1@BUPD9(M\)&2)R(G*P>`%#ZS:
M&XG&"=:+5"1LB?`#1"1P,<F+="10B40D<(M$)&B)TXE,)'2)P0^DPQ[!X1X/
MK-`""<'!Z@*)R(E,)"`+3"10"=,AQB-,)&")1"0H,=()\8M$)#`#A"0``@``
MB5PD)(G.BTPD<(M<)'0%W+P;CP'&B50D+(G(#ZS9&\'@!0G(`<8QR8M$)'")
M\S'VB4PD%(M,)"")="1LBW0D8(E<)&B)\@^L_@+!XAX)U@GQB70D4"'(BTPD
M*(ET)!`A\0G(BTPD&`.,)`@"``"!P=R\&X\!P8E,)&"+3"1HBUPD;(M\)&R)
MR(G*P>`%#ZS:&XG&"=:+5"1TB?`#1"1@,<F+="10B40D8(M$)'")TXE,)&2)
MP0^DPQ[!X1X/K-`""<'!Z@*)R(E,)"`+3"10"=,AQB-,)&B)1"0P,=()\8M$
M)"@#A"00`@``B5PD)(G.BTPD8(M<)&0%W+P;CP'&B50D-(G(#ZS9&\'@!0G(
M`<8QR8M$)&")\S'VB4PD'(M,)"")="1TBW0D:(E<)'")\@^L_@+!XAX)U@GQ
MB70D4"'(BTPD,(ET)!@A\0G(BTPD$`.,)!@"``"!P=R\&X^+7"1TBWPD=`'!
MB4PD:(M,)'")R(G*P>`%#ZS:&XG&"=:+5"1DB?`#1"1H,<F+="10B40D:(M$
M)&")TXE,)&R)P0^DPQ[!X1X/K-`""<'!Z@*)R(E,)"`+3"10"=,AQB-,)'")
M1"0H,=()\8M$)#`#A"0@`@``B5PD)(G.BTPD:(M<)&P%W+P;CP'&B50D+(G(
M#ZS9&\'@!0G(`<8QR8M$)&B)\S'VB4PD%(M,)"")="1DBW0D<(E<)&")\@^L
M_@+!XAX)U@GQB70D4"'(BTPD*(ET)!`A\0G(BTPD&`.,)"@"``"!P=R\&X^+
M7"1DBWPD9`'!B4PD<(M,)&")R(G*P>`%#ZS:&XG&"=:+5"1LB?`#1"1P,<F+
M="10B40D<(M$)&B)TXE,)'2)P0^DPQ[!X1X/K-`""<'!Z@*)R(E,)"`+3"10
M"=,AQB-,)&`QTHE$)#`)\8M$)"@#A"0P`@``B5PD)(G.BTPD<(M<)'0%W+P;
MCP'&B50D-(G(#ZS9&\'@!0G(BTPD(`'&BT0D<(GS,?:)="1LBW0D8(E<)&B)
M\@^L_@+!XAX)U@GQB70D4"'(B70D&(M,)#"+7"1LBWPD;"'Q"<B+3"00`XPD
M.`(``('!W+P;CP'!B4PD8(M,)&B)R(G*P>`%#ZS:&XG&"=:+5"1TB?`#1"1@
M,<F+="10B40D8(M$)'")3"1DB<$/K-`",=+!X1Z)5"0L"<&)R(E,)'`+3"10
M(<8C3"1HBU0D<(E$)"@)\8M$)#`#A"1``@``!=R\&X^)RXM,)&`!PXG>BUPD
M9(G(P>`%#ZS9&PG(`<:+1"1@B?,Q]HET)%2+="1HB5PD4(G[B?$/I/,>P>$>
M#ZS^`L'O`@GQ"?N)WHG+,<F)7"0@"=J)3"0D(=")7"1HBTPD*(ET)&R+="08
M(=F+7"14BU0D;`G(`[0D2`(``(GQB<:!P=R\&X\!SHM,)%")R`^LV1O!X`4)
MR`'&,?^)="1PBW0D8(E\)'2+?"1DB?&)^\'A'@^D\QX/K/X"B?")WHG+P>\"
M"<.+1"1H"?XQR8GWB5PD,(G>B=.)3"0TB<$)^R-$)#`)\8ET)&"+="10B7PD
M9(M\)%0C5"0T(?$A^PG!BT0D*`G3`X0D4`(``(M4)"P3E"14`@``!=R\&X^#
MT@`!P1'3B4PD:(M,)'")7"1LBUPD=(G(P>`%#ZS9&XG["<B+3"1H`<$/I/,>
MB<J)3"0H,<F)5"1HB4PD;(GQ#ZS^`L'A'L'O`HGPB=X)_HG+BTPD((M\)&P)
MPXGR,?:)V(E<)!"+7"1@B70D%(MT)&0)PXE$)%`)UHE4)%2)V(M<)%`C1"1P
M(UPD,(GRBW0D5"-4)'0)V"-T)#2+7"0D"?(#C"18`@``$YPD7`(``('!W+P;
MCXMT)&B#TP`!P1'3B?")3"1@BU0D=(E<)&2)\\'@!0^L^QL)V(M<)&`!PXM$
M)'`QR8E,)&2)QHE<)"#!YAZ)7"1@B?&)Q@^LU@*)\(G."<:+1"10B70D4#'P
MBW0D,#-$)"@#M"1@`@``BUPD9(GQB<:!P=;!8LH!SHM,)&")R`^LV1N+7"1L
MP>`%"<@!QC')B4PD=(M,)&B)="1PB<B)="08#ZS9`C';P>`>B<:+1"00"<Z+
M3"0@B?*+="10B50D,#'6BU0D%#'Q`X0D:`(``!.4)&P"```%UL%BRH/2``'!
M$=.)3"1HBTPD<(E<)&R+7"1TB<B)WHG+P>`%BTPD:`^L\QN+="0P"=B+7"1D
M`<&)RHE,)"`QR8E,)&R+3"1@B50D:(G(#ZS9`HN<)'`"``#!X!X)R('#UL%B
MRHE$)"B+1"10B=D!P3-T)"B+1"08B<N+3"1H,?`!PXG(B=Z+7"1LP>`%#ZS9
M&XM<)'0)R(M,)'`!QC'2B<B)="08#ZS9`HN<)'@"``#!X!Z)="1@B<:+1"0@
MB50D9`G.@</6P6+*B70D4(NT)'P"``")V8/6`#'_B?.+="0P`?&+="0H$?LS
M="10,=(Q\`'!$=.)3"1PBTPD8(E<)'2+7"1DB<B)WHG+P>`%BTPD<`^L\QN+
M="10"=B+7"1L`<&)RHE,)"`QR8E,)'2+3"1HB50D<(G(#ZS9`HN<)(`"``#!
MX!X)R('#UL%BRHE$)#"+1"0HB=D!P8M$)!@S="0PB<N+3"1P,?`!PXG(B=Z+
M7"1TP>`%#ZS9&XM<)&0)R(M,)&`!QC'2B<B)="08#ZS9`HN<)(@"``#!X!Z)
M="1HB<:+1"0@B50D;`G.@</6P6+*B70D*(NT)(P"``")V8/6`#'_B?.+="10
M`?&+="0P$?LS="0H,=(Q\`'!$=.)3"1@BTPD:(E<)&2+7"1LB<B)WHG+P>`%
MBTPD8`^L\QN+="0H"=B+7"1T`<&)RHE,)"`QR8E,)&2+3"1PB50D8(G(#ZS9
M`HN<))`"``#!X!X)R('#UL%BRHE$)%"+1"0PB=D!P8M$)!@S="10B<N+3"1@
M,?`!PXG(B=Z+7"1DP>`%#ZS9&PG(`<8QTHET)!B)="1PBTPD:(M<)&R)5"1T
MB<C!X!X/K-D"BYPDF`(``(G&BT0D(`G.@</6P6+*B70D,(NT))P"``")V8/6
M`#'_B?.+="0H`?&+="10$?LS="0P,=(Q\`'!$=.)3"1HBTPD<(E<)&R+7"1T
MB<B)WHG+P>`%BTPD:`^L\QN+="0P"=B+7"1D`<&)RHE,)"`QR8E,)&R+3"1@
MB50D:(G(#ZS9`HN<)*`"``#!X!X)R('#UL%BRHE$)"B+1"10B=D!P8M$)!@S
M="0HB<N+3"1H,?`!PXG(B=Z+7"1LP>`%#ZS9&PG(BTPD<`'&,=*)="08B<B)
M="1@P>`>B50D9(M<)'2)QHM$)"`/K-D"BYPDJ`(```G.B70D4(NT)*P"``"!
MP];!8LJ)V8/6`#'_B?.+="0P`?&+="0H$?LS="10,=(Q\`'!$=.)3"1PBTPD
M8(E<)'2+7"1DB<B)WHG+P>`%BTPD<`^L\QN+="10"=B+7"1L`<&)RHE,)"`Q
MR8E,)'2+3"1HB50D<(G(#ZS9`HN<)+`"``#!X!X)R('#UL%BRHE$)#"+1"0H
MB=D!P8M$)!@S="0PB<N+3"1P,?`!PXG(B=Z+7"1TP>`%#ZS9&XM<)&0)R(M,
M)&`!QC'2B<B)="08#ZS9`L'@'HET)&B)QHE4)&P)SHET)"B+G"2X`@``B[0D
MO`(``(M$)""!P];!8LJ#U@")V3'_B?.+="10`?&+="0P$?LS="0H,=(Q\`'!
M$=.)3"1@BTPD:(E<)&2+7"1LB<B)WHG+P>`%BTPD8`^L\QN+="0H"=B+7"1T
M`<&)RHE,)"`QR8E,)&2+3"1PB50D8(G(#ZS9`HN<),`"``#!X!X)R('#UL%B
MRHE$)%"+1"0PB=D!P8M$)!@S="10B<N+3"1@,?`!PXG(B=Z+7"1DP>`%#ZS9
M&XM<)&P)R(M,)&@!QC'2B<B)="08#ZS9`HN<),@"``#!X!Z)="1PB<:)5"1T
M"<Z!P];!8LJ)="0PB[0DS`(``(G9@]8`,?^)\XMT)"B+1"0@`?&+="10$?LS
M="0P,=(Q\`'!$=.)3"1HBTPD<(E<)&R+7"1TB<B)WHG+P>`%BTPD:`^L\QN+
M="0P"=B+7"1D`<&)RHE,)"`QR8E,)&R+3"1@B50D:(G(#ZS9`HN<)-`"``#!
MX!X)R('#UL%BRHE$)"B+1"10B=D!P8M$)!@S="0HB<N+3"1H,?`!PXG(B=Z+
M7"1LP>`%#ZS9&XM<)'0)R(M,)'`!QC'2B<B)="08#ZS9`HN<)-@"``#!X!Z)
M="1@B<:)5"1D"<Z!P];!8LJ)="10B[0DW`(``(G9@]8`,?^)\XMT)#`!\8MT
M)"@1^S-T)%"+1"0@,=(Q\`'!$=.)3"1PBTPD8(E<)'2+7"1DB<B)WHG+P>`%
MBTPD<`^L\QN+M"3D`@``"=B+7"1L`<&)RHE,)"`QR8E,)'2+3"1HB50D<(G:
M#Z3*'HG(#ZS9`L'K`L'@'@G:BYPDX`(```G(B40D,(M$)!B!P];!8LJ)5"0T
M@]8`B=DQ_XGSBW0D*`'QBW0D4!'[,W0D,#'2,?")WHG+BTPD<`'#$=:)R#'2
MB?>)WHM<)'3!X`4/K-D;BUPD9`G(BTPD8`'&$=<QTHG(B70D&(E4)&R)VL'@
M'@^DRAZ)?"0<#ZS9`HET)&C!ZP*)QHG7"<X)WXN<).@"``")="0HB[0D[`(`
M`('#UL%BRHE\)"R#U@")V3'_B?.+="10BT0D(`'QBW0D,!'[,W0D*#'2BWPD
M;#'PBW0D:`'!$=.)\(E,)&"+3"1@B5PD9(GSP>`%,=(/K/L;"=B+7"1D`<$1
MTXE,)"")RC')B4PD9(M,)'")7"0DBUPD=(G(B50D8,'@'HG:#Z3*'HG&#ZS9
M`HM$)#`)SHN,)/`"``#!ZP*)UPG?BUPD9(M4)&R)="10@<'6P6+*BW0D*(E\
M)%0!P8M$)!@S="10,?")SHM,)&`!QHG(#ZS9&\'@!0G(`<:+1"1H,?^)="1P
MB=:)PP^DQAZ)?"1TP>,>#ZS0`HG9P>H"B?,)P0G3BT0D2(E,)&B)7"1L`X0D
M^`(``(M,)"@%UL%BRHM<)%`!R(M,)"`S7"1HB<8QV8M<)'0!SHM,)'")R`^L
MV1N+7"1<P>`%"<B+3"1H`<8Q_XM$)'`#1"1`B3.+="1@,=*)>P2+?"1DB4,(
MB?#!X!X/K/X"BWPD7(E3#`GP`T0D>#'2`TPD.(E7%#'2B4<0BT0D4(E7'`-$
M)`@QTHE/&(E'((E7)(N$)`P#``!E*P44````=0B-9?1;7E]=P^C^!```+HVT
M)@````"-M@````#S#Q[[C4PD!(/D\/]Q_%6)Y5/H>;K__X'#+7,``%&#[`QJ
M?.B8MO__9@]O@YSA__^#Q!#'0#``````#Q$`9@]O@ZSA___'0#0`````#Q%`
M$&8/;X.\X?__QT!X``````\10""-9?A96UV-8?S#C78`\P\>^^@AV?__!<MR
M``"-3"0$@^3P_W'\58GE5U9348/L*(E%S(M!!(LYB478BT$(B<.9B47<P>,#
MB574B=D#3R@QTHE%T#M/*(M',(E5Y(M7-(M=Y(E-X!M?+',&@\`!@](`BUW@
MBTW0BW7DB5\HBUW4B7<LC7<X#ZS9'<'K'0'!BT=X$=.)3S")7S2%P`^%#`$`
M`(M%W(/X/WY[B<*)?>")]\'J!HG3C4+_BU78P>,&B470C0P:B=:)RRZ-="8`
M\P]O!HM%X(/&0`\1!_,/;T;0#Q%'$/,/;T;@#Q%'(/,/;T;P#Q%',.A3V/__
M.=YUSXM%T(M5W(G^BWW@B<'!X`;WV<'A!HU4"L")5=R+5=B-1`)`B478BU7<
M@_H$<EF+5=B+`HE'.(M=W(M$&OR)1![\C4<\@^#\*<8I\@'>@^;\B=&#_@1R
M&(/F_#';BQ09B108@\,$.?-R\XVV`````(M%W(E'>(UE\%E;7E]=C6'\PXVV
M`````(72=.2+1=B#X@(/M@"(1SATUHM%V(M5W`^W1!#^9HE$%O[KQ(UT)@"+
M5=RY0````"G!.=$/3\J#[`0!\%&)3>#_==A0BUW,Z`RT__^+1WB+3>"#Q!`!
MR(E'>(/X0'6/B?@I3=P!3=CH7-?__^FK_O__C;0F`````/,/'OOH,=?__P7;
M<```C4PD!(/D\/]Q_%6)Y5=64U&#[!B+602+,8E%Y(M#*(M3+`_(B<>+0S`/
MR(E%X(M#*`^LT`.#X#^-4`'&1`,X@(U,$SB#^C@/CB4!``"X0````"G0=!HQ
MTJ@!#X6R`0``Q@01`,9$$0$`@\(".<)R\(G8Z,O6__]F#^_`#Q%#6`\10S@/
M$4-(#Q%#8(M%X(E[=(E#<(G8Z*?6__^+4P2+`X/L#`^LT!B(!HM3!(L##ZS0
M$(A&`8L#B&8"BP.(1@.+4PR+0P@/K-`8B$8$BU,,BT,(#ZS0$(A&!8M#"(AF
M!HM#"(A&!XM3%(M#$`^LT!B(1@B+4Q2+0Q`/K-`0B$8)BT,0B&8*BT,0B$8+
MBU,<BT,8#ZS0&(A&#(M3'(M#&`^LT!"(1@V+0QB(9@Z+0QB(1@^+4R2+0R`/
MK-`8B$80BT,@BU,D#ZS0$(A&$8M#((AF$HM#((A&$U.+7>3HXK'__X/$$(UE
M\%E;7E]=C6'\PXUV`+@X````*="#^`1R=(U1!,<!`````(/B_,=$`?P`````
M*=$!R(/@_(/X!`^"Z?[__XG!@^'\B4W8C4C_P>D"B4W<N00```#'`@`````Y
MP0^#Q?[___9%W`%U7L<$"@````#'1`H$`````(/!"#M-V'+IZ:/^__\NC;0F
M`````&:0A<`/A)'^___&`0"H`@^$AO[__S'29HE4`?[I>O[__Y"Z`0```,8!
M`#G"#X(^_O__Z4G^__^-=@#'0@0`````N0@````[3=ARD>E+_O__BSPDPV:0
M9I!FD&:09I!FD&:04^C*M?__@<-^;@``@^P(_[,@`0``_W0D'/]T)!S_="0<
MZ$JP__^#Q!A;PV:09I"04^B:M?__@<-.;@``@^P(Z-RQ__]3@^P(Z(.U__^!
MPS=N``"#Q`A;PP``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````,````!``(`)7,O)7,`+W!R;V,O<V5L9B]E>&4`1'EN84QO861E
M<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"]P<F]C
M+R5I+R5S`"X`4$%27U1%35``4$%27U!23T=.04U%`#H`+P!015),-4Q)0@!0
M15),3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-0
M05=.140`4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T=,3T)!
M3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'3$]"
M04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`#$`;'-E96L@9F%I;&5D`')E860@
M9F%I;&5D`$Q$7TQ)0E)!4EE?4$%42`!365-414T`+W1M<`!414U01$E2`%1-
M4`!54T52`%5315).04U%`"4P,G@`<&%R+0`E<R5S)7,E<P!P87)L`"YP87(`
M<VAO<G0@<F5A9``E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T
M96UP+25U+25U)7,`&`!P97)L`#``4$%2.CI086-K97(Z.E9%4E-)3TX`,2XP
M-C0`+64`+2T`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T
M;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER
M96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T
M<GD@>6]U<B!O<&5R871I;VXI"@``56YA8FQE('1O(&-R96%T92!C86-H92!D
M:7)E8W1O<GD`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B
M9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@````!E=F%L("=E>&5C
M("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@
M<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY
M("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?<VEZ92P@)&-A8VAE7VYA;65?
M<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*)$9)
M3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I"B1C86-H95]N86UE
M7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P,UPP,#0B.PI]"G-U
M8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I(#T@0%\["FUY("1C:'5N:U]S
M:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1F:#L*
M;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E("1C:'5N:U]S:7IE
M.R`@("`@(",@3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S
M:7IE"G=H:6QE("@D<&]S(#X](#`I('L*<V5E:R`D9F@L("1P;W,L(#`["G)E
M860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#
M*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@
M,"D@>PIR971U<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4[
M"GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M
M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!
M3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N
M86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG
M(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T
M:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I
M.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE
M("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,
M051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER
M;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L
M"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP
M(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR
M9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*
M8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F
M:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M
M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS
M>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E
M<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'
M24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E
M<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@
M("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N
M97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3
M,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q
M6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D[
M"F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI
M.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD["DU!
M1TE#.B!["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIU;FQE<W,@
M*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*;W5T<RAQ<5M#86XG
M="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@
M)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]
M"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M
M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I
M;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-
M04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@<&]S:71I;VX@)&UA
M9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E
M=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E860@7T9(+"`D8G5F
M+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@(EPP0T%#2$4B("8F
M("1B=68@;F4@(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A8VAE(&UA<FME<B!F
M;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U=',H<7%;0V%C:&4@;6%R:V5R("(D
M8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F
M9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)3$5?;V9F<V5T7W-I
M>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F
M<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E="(I.PIS965K(%]&
M2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@)&]F9G-E="P@
M,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@7T9(.PIM>2`E<F5Q
M=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@
M("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U
M9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D
M8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*
M;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D
M8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D
M,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\
M*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E
M>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D
M9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE
M.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA
M;64["GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@
M/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PHD
M<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@
M-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@
M/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D
M:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D
M:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO
M9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%2
M7T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E
M('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D
M:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*
M96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN
M<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE
M.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#
M86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE
M(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO
M9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!0
M05(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R
M=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR
M97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@
M:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N
M86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M
M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@
M>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O
M;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M
M97T["GT*:68@*"1B=68@;F4@)%!+6DE07TU!1TE#*2!["F]U=',H<7%;3F\@
M>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA
M;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I
M("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R
M7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE
M*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%
M55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"FEF("@A)'-T87)T7W!O
M<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@
M>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T
M86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E
M<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S
M92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF
M="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@
M0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH
M6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG
M*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I
M('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI
M9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@
M/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<[
M"GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS
M:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G
M3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O
M<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2![
M"B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M
M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT[
M"FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z
M.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH
M)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T
M;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY
M("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P
M87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A
M;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/
M.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR
M96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV
M92`B)'!A<B)=.PI]"FUY("5M971A7W!A<B`](&1O('L*:68@*"1Z:7`@86YD
M(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE
M=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD
M;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN
M960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@
M<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*
M<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R
M(&9I;&5=('5N;&5S<R`D8G5F(&5Q("102UI)4%]-04=)0SL*8VQO<V4@)'!H
M.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?4D17
M4B@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;
M0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I
M.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@)'-T
M87)T7V]F7T9)3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@)&QO861E<BP@)'-T
M87)T7V]F7T9)3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E
M9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA
M<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^<')I;G0H)&QO861E<BD*;W(@
M9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D;W5T(CH@)"%=.PII
M9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U
M;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D
M8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA
M<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E
M>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*
M;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S
M:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O
M;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI8E]E>'0@
M=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T
M(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H9&5F:6YE
M9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H
M(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ
M*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*
M:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*:68@*&UY
M("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@
M*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL
M92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE
M>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T96Y[)&YA
M;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1
M)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B
M)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D[
M"FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F
M:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M
M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R96%D("(D
M9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E
M9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]
M?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E
M;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"B1F
M:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI
M+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#
M,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E
M;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D
M9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;5W)I='1E;B!A<R`B
M)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW<FET951O1FEL94AA
M;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R
M<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*?0II9B`H)&UE=&%?
M<&%R>V-L96%N?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.(BD["GT*96QS92![
M"FEF("@A9&5F:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D8W1X(#T@1&EG97-T
M.CI32$$M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C='@M/F%D9&9I;&4H
M)&9H*3L*<V5E:R`D9F@L(#`L(#(["B1C86-H95]N86UE(#T@)&-T>"T^:&5X
M9&EG97-T.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P
M+"`D8V%C:&5?;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C
M86-H95]N86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD9F@M/G!R
M:6YT*"1C86-H95]N86UE+`HB7#!#04-(12(I.PI]"FUY("1O9F9S970@/2`D
M9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BD["B1F:"T^<')I;G0H<&%C:R@G
M3B<L("1O9F9S970I+`HD4$%27TU!1TE#*3L*)&9H+3YC;&]S92!O<B!D:64@
M<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO
M9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D
M<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&
M:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E
M.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF
M:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D
M(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z
M:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N
M86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D[
M"G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P
M<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG('II<"XN+B(I.PII
M9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@
M870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M
M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE
M;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M
M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE
M(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%
M3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA
M;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*
M;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E
M861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ
M<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BXN
M+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X
M=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P
M-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N
M;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB
M('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I
M<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD
M,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!2
M3T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U
M8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z
M.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE
M.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I
M<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE
M<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@
M<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO
M861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER
M92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I
M<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR
M97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER
M92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L
M93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*
M<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E
M<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$
M:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,[
M"F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!]
M.PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I
M<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I
M93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)
M3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U
M=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P
M87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM
M87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%
M35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL
M97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*
M;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T
M<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS
M,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA
M;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P
M=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@
M)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T
M:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[
M4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@
M>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#
M86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O
M<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*<V5E:R`D9F@L("1M
M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(
M12(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@;&5N9W1H*")<,$-!
M0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@)&UA
M9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%
M(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D("1F:"P@)&)U9BP@)&-A
M8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD8V%C:&5?9&ER(#T@
M(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF("@A)&-A8VAE7V1I
M<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6>U!!4E]#3$5!3GT@
M/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7TD8V%C:&5?9&ER(CL*
M;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%27U1%35!](#T@)'-T;7!D
M:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@
M86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@
M>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL
M;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M
M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;7D@)&9H.PHH
M;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@*'!R:6YT("1F:"`D
M8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q<5M%<G)O<B!W<FET
M:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@
M:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE
M*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]
M"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/
M1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P
M<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!
M4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@
M/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H
M)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!
M4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI
M(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR
M971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE
M?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E='5R;CL*?0I]"F9O
M<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%
M3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD
M("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421S>7-[7V1E
M;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R
M;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E
M;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER
M)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y
M<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*
M)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN
M9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE
M(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F
M:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE
M9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D[
M"F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[
M7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D
M14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS
M92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!
M5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E
M;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#
M3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@)$5.5GLB4$%27T=,
M3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/0D%,7R1?(GT["GT*
M:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT[
M"GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I
M('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB
M.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.
M0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H
M"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP
M"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN
M.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87([
M"E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T
M(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O
M<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N
M86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD
M*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D
M0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58
M251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U([
M"C$["E]?14Y$7U\*``!#04-(10``<&5R;'AS:2YC````_____P````#_____
M``````$C16<`````B:O-[P````#^W+J8`````'94,A``````\.'2PP``````
M``````````$;`SL8`0``(@```'!?__]@`0``\&+__X0!```08___-`H``%!E
M__\T`0``D&;__Y@!``!@9____`$``/!G__](`@``@&G__P@#``#P:___B`,`
M`,!L__\8!```(&W__V@$``!@;?__E`0``#!N__\L!0``0&[__T`%``"`</__
M0`8``,!P__]P!@```'+__^@&```P=O__*`<``*!V__]$!P``X';__VP'``!P
M>/__'`@``*!X__]("```@'G__\`(``#`@?__"`D``,"#___8"0``BH3__WP*
M``".A/__D`H``*"$__^D"@``\*K__]@*``!@J___$`L``%"M__]8"P``GJ__
M_Z`+``"PK___M`L``."O___@"P``%``````````!>E(``7P(`1L,!`2(`0<(
M$````!P````49/__+``````````4``````````%Z4@`!?`@!&PP$!(@!```@
M````'`````A>__^``P````X(1@X,2@\+=`1X`#\:.RHR)"(0````0````&1A
M__\(`````````&````!4````\&3__\$`````00X(A0)##@R'`T$.$(8$00X4
M@P5.#C!_#C1!#CA$#CQ!#D!(#C!:"@X40\,.$$'&#@Q!QPX(0<4.!$<+;@H.
M%$/##A!!Q@X,0<<."$'%#@1!"P!(````N````%QE__^"`````$$."(8"00X,
M@P-.#H@!4@Z,`4$.D`%(#H`!80Z(`4(.C`%!#I`!2`Z``6,*#@Q!PPX(0<8.
M!$$+````O`````0!``"@9?__C@$```!!#@B%`D$.#(<#00X0A@1!#A2#!5$.
MH`%M"@X40<,.$$'&#@Q!QPX(0<4.!$H+0PZL`4$.L`%(#J`!20ZL`4$.L`%(
M#J`!<PZL`4$.L`%J#JP!1PZH`40.K`%!#K`!00ZT`40.N`%"#KP!00[``4@.
MJ`%%#JP!00ZP`4@.H`%8#JP!00ZP`4@.H`%##JP!00ZP`4@.H`%##JP!00ZP
M`4@.H`%4#JP!00ZP`5`.H`$`?````,0!``!P9O__:P(```!!#@B%`D$.#(<#
M00X0A@1!#A2#!4X.7%D.8$@.4%H.7$,.8$@.4`)3#EQ-#F!,#E`";PH.%$'#
M#A!!Q@X,0<<."$'%#@1)"P)K#EQ$#F!6#E!?#E1!#EA$#EQ%#F!0#E!=#EA$
M#EQ!#F!,#E````",````1`(``&!H___%`````$$."(4"00X,AP-!#A"&!$$.
M%(,%1@Z4($<.Q"!@#L@@30[,($$.T"!(#L`@70[$($$.R"!!#LP@0P[0($@.
MP"!6"@X40<,.$$'&#@Q!QPX(0<4.!$$+1P[$($$.R"!&#LP@00[0($@.P"!.
M#L0@00[(($$.S"!##M`@2`[`(`!,````U`(``*!H__]>`````$4."(8"00X,
M@P-.#A!-#A1,#AA!#AQ##B!&#AQ'#AA"#AQ!#B!!#B1'#BA'#BQ##C!(#@Q!
MPPX(0<8.!````"@````D`P``L&C__SH`````10X(@P).#A!'#A1,#AA!#AQ)
M#B!(#@A!PPX$E````%`#``#$:/__T`````!%#@B%`D$.#(<#00X0A@1!#A2#
M!48.E"!*#I1`1P[`0&(.R$!'#LQ`00[00$<.U$!%#MA`0@[<0$4.X$!(#L1`
M10[(0$@.S$!!#M!`2@[`0$<.S$!&#M!`3`[`0$H.Q$!!#LA`00[,0$$.T$!,
M#L!`5@H.%$/##A!!Q@X,0<<."$'%#@1!"P`0````Z`,``/QH__\)````````
M`/P```#\`P``^&C__SD"````10X(A0)!#@R'`T$.$(8$00X4@P5&#I0@2@ZP
M(7\.N"%"#KPA0P[`(4@.L"%M"@X40<,.$$'&#@Q!QPX(0<4.!$L+0PZ\(4$.
MP"%&#KPA00ZX(4L.O"%!#L`A2`ZP(7(.N"%!#KPA00[`(4@.L"%'#KPA00[`
M(4@.L"%G#KPA00[`(4@.L"%%#KPA1`[`(4@.L"%.#K@A1`Z\(4(.P"%(#K`A
M`DL.M"%$#K@A1`Z\(4$.P"%$#L0A10[((4(.S"%(#M`A2`ZX(40.O"%!#L`A
M2`ZP(5\.N"%"#KPA00[`(4@.L"%8#KPA00[`(4@.L"$L````_`0``#AJ__\V
M`````$4."(8"00X,@P-.#AA&#AQ!#B!8#@Q!PPX(0<8.!`!T````+`4``$AJ
M__\T`0```$4."(4"00X,AP-!#A"&!$$.%(,%1@Z4($<.P"!T#LP@00[0($@.
MP"`"0`[(($(.S"!!#M`@3`[`(%(.S"!!#M`@2`[`(%8*#A1!PPX00<8.#$''
M#@A!Q0X$2@M##LP@1P[0($@.P"`\````I`4``!!K__\N!````$4."(4"00X,
MAP-!#A"&!$P.%(,%0PY``^0#"@X41\,.$$'&#@Q!QPX(0<4.!$4+&````.0%
M````;___:0````!1#B`"1`H.!$L+`"0`````!@``5&___S<`````10X(@P).
M#A!%#A1$#AA(#AQ"#B````"L````*`8``&QO__^$`0```$$."(4"00X,AP-!
M#A"&!$$.%(,%1PP#E(`$3@T$0P[`@`1=#L2`!$(.R(`$0@[,@`1!#M"`!`)"
M#L"`!%(.Q(`$1`[(@`1$#LR`!$$.T(`$2`[`@`1.#L2`!$4.R(`$00[,@`1!
M#M"`!$@.P(`$`F@*#A1!PPX00<8.#$''#@A!Q0X$1`MT"@[,@`1'#M"`!$4+
M0PH.S(`$1P[0@`1%"R@```#8!@``3'#__R\`````10X(@P).#A!(#AQ!#B!(
M#A!)#@A!PPX$````=`````0'``!0</__V`````!%#@B%`D$.#(<#00X0A@1!
M#A2#!4X.0'T*#A1%PPX00<8.#$''#@A!Q0X$10M'#DQ!#E!J#D1,#DA!#DQ'
M#E!!#E1$#EA"#EQ!#F!(#D!0"@X41<,.$$'&#@Q!QPX(0<4.!$4+````1```
M`'P'``"X</__,@@```!3#`$`21`%`G4`1`\#=7`&$`<"=7P0!@)U>!`#`G5T
M`ST#"L$,`0!!PT'&0<=!Q4,,!`1$"P``S````,0'``"P>/__]P$```!%#@B%
M`D$.#(<#00X0A@1!#A2#!4X.,`))#C1"#CA!#CQ!#D!(#C!)#C1'#CA%#CQ#
M#D!+#C!4#C1"#CA!#CQ##D!(#C!C#C1!#CA!#CQ##D!(#C!##C1(#CA!#CQ#
M#D!(#C1'#CA!#CQ##D!<#C!/#CA%#CQ!#D!(#C!E"@X40<,.$$'&#@Q!QPX(
M0<4.!$0+0PH./$8.0$@.,$\./$<.0$D+<PXX00X\0PY`2`XP1@H.-$<..$(.
M/$<.0$4+`%@```"4"```X'G__\H`````10X(A@)!#@R#`TX.,`)-"@X,0<,.
M"$'&#@1%"T,./$$.0$8./$$..$(./$$.0&`.-$@..$$./$$.0$@.,%0*#@Q#
MPPX(0<8.!$4+1````/`(``#46/__.P(```!(#`$`21`%`G4`01`'`G5\1!`&
M`G5X$`,"=71,#P-U<`8#80$*P0P!`$'#0<9!QT'%0PP$!$$+$````#@)```&
M>O__!``````````0````3`D``/9Y__\$`````````#````!@"0``]'G__T(F
M````00X(A0)"#05!AP-6A@2#!0,?)@K#0<9!QT'%#`0$00L````T````E`D`
M`!"@__]M`````$@,`0!)$`4"=0!!$`,"=7Q,#P-U>`8"2<$,`0!!PT'%0PP$
M!````$0```#,"0``2*#__^D!````4@P!`$D0!0)U`$0/`W5P!A`'`G5\$`8"
M=7@0`P)U=`-+`0K!#`$`0<-!QD''0<5##`0$1PL``$0````4"@``\*'__TX"
M````4@P!`$D0!0)U`$0/`W5P!A`'`G5\$`8"=7@0`P)U=`-6`0K!#`$`0<-!
MQD''0<5##`0$1`L``!````!<"@``]J/__P0`````````*````'`*``#TH___
M*P````!!#@B#`DX.$$8.%$0.&$0.'$0.($@."$'##@08````G`H``/BC__\4
M`````$$."(,"3@X0``````````0````0`````0```$=.50```````P````(`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"`7``#0%@```0````\#```!````'P,```P`````$```#0```*1@```9
M````W,T``!L````$````&@```.#-```<````!````/7^_V\T`@``!0```+0&
M```&````5`(```H```"+`P``"P```!`````5``````````,```#DS@```@``
M`+@!```4````$0```!<```#T"P``$0```&P+```2````B````!,````(````
M'@````@```#[__]O`0``"/[__V_,"@``____;P$```#P__]O0`H``/K__V\%
M`````````````````````````````````````````````````````````.3-
M`````````````#80``!&$```5A```&80``!V$```AA```)80``"F$```MA``
M`,80``#6$```YA```/80```&$0``%A$``"81```V$0``1A$``%81``!F$0``
M=A$``(81``"6$0``IA$``+81``#&$0``UA$``.81``#V$0``!A(``!82```F
M$@``-A(``$82``!6$@``9A(``'82``"&$@``EA(``*82``"V$@``QA(``-82
M``#F$@``]A(```83```6$P``)A,``#83``!&$P``5A,``&83``!V$P``AA,`
M`)83````````````````````````````````````````````````````````
M``````````#`$P````````30```*4$%2+G!M"@````#L<@``1T-#.B`H36%G
M96EA(#$U+C$N,"TQ+FUG83$P*2`Q-2XQ+C```"YS:'-T<G1A8@`N;F]T92YG
M;G4N8G5I;&0M:60`+FYO=&4N9VYU+G!R;W!E<G1Y`"YI;G1E<G``+F=N=2YH
M87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N
M7W(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G!L="YG;W0`+G1E>'0`+F9I
M;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N;F]T92Y!0DDM
M=&%G`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YD871A`"YB
M<W,`+F-O;6UE;G0`````````````````````````````````````````````
M```````````+````!P````(```#4`0``U`$``"0```````````````0`````
M````'@````<````"````^`$``/@!```H```````````````$`````````#$`
M```!`````@```"`"```@`@``$P```````````````0`````````Y````]O__
M;P(````T`@``-`(``"`````%``````````0````$````0P````L````"````
M5`(``%0"``!@!```!@````$````$````$````$L````#`````@```+0&``"T
M!@``BP,``````````````0````````!3````____;P(```!`"@``0`H``(P`
M```%``````````(````"````8````/[__V\"````S`H``,P*``"@````!@``
M``$````$`````````&\````)`````@```&P+``!L"P``B`````4`````````
M!`````@```!X````"0```$(```#T"P``]`L``+@!```%````%P````0````(
M````@0````$````&`````!`````0```@```````````````$`````````'P`
M```!````!@```"`0```@$```@`,`````````````$`````0```"'`````0``
M``8```"@$P``H!,```@```````````````@````(````D`````$````&````
MP!,``,`3``#D3``````````````@`````````)8````!````!@```*1@``"D
M8```%```````````````!`````````"<`````0````(`````<````'```+!`
M`````````````!``````````I`````$````"````L+```+"P```<`0``````
M```````$`````````+(````!`````@```,RQ``#,L0``Y`H`````````````
M!`````````"\````!P````(```"PO```L+P``"````````````````0`````
M````R@````X````#````W,T``-R]```$```````````````$````!````-8`
M```/`````P```.#-``#@O0``!```````````````!`````0```#B````!@``
M``,```#DS0``Y+T````!```&``````````0````(````BP````$````#````
MY,X``.2^```<`0`````````````$````!````.L````!`````P````#0````
MP```&```````````````!`````````#Q````"`````,````8T```&,```!0`
M``````````````0`````````]@````$````P`````````!C````D````````
M```````!`````0````$````#```````````````\P```_P``````````````
(`0``````````
